| Home | Libraries | People | FAQ | More

### Finding the Next Smaller Representable Value (float_prior)

##### Synopsis

    #include <boost/math/special_functions/next.hpp>

    namespace boost{ namespace math{

    template <class FPT>
    FPT float_prior(FPT val);

    }} // namespaces

##### Description - float_prior

Returns the next representable value which is less than x. If x is non-finite then returns the result of a domain_error. If there is no such value less than x then returns an overflow_error.

Has the same effect as

    nextafter(val, -(std::numeric_limits<FPT>::max)());  // Note most negative value -max.